Vp9Packet

Struct Vp9Packet 

pub struct Vp9Packet {
Show 24 fields pub i: bool, pub p: bool, pub l: bool, pub f: bool, pub b: bool, pub e: bool, pub v: bool, pub z: bool, pub picture_id: u16, pub tid: u8, pub u: bool, pub sid: u8, pub d: bool, pub pdiff: Vec<u8>, pub tl0picidx: u8, pub ns: u8, pub y: bool, pub g: bool, pub ng: u8, pub width: Vec<u16>, pub height: Vec<u16>, pub pgtid: Vec<u8>, pub pgu: Vec<bool>, pub pgpdiff: Vec<Vec<u8>>,
}
Vp9Packet represents the VP9 header that is stored in the payload of an RTP Packet

Fields

i: bool

picture ID is present

p: bool

inter-picture predicted frame.

l: bool

layer indices present

f: bool

flexible mode

b: bool

start of frame. beginning of new vp9 frame

e: bool

end of frame

v: bool

scalability structure (SS) present

z: bool

Not a reference frame for upper spatial layers

picture_id: u16

Recommended headers 7 or 16 bits, picture ID.

tid: u8

Conditionally recommended headers Temporal layer ID

u: bool

Switching up point

sid: u8

Spatial layer ID

d: bool

Inter-layer dependency used

pdiff: Vec<u8>

Conditionally required headers Reference index (F=1)

tl0picidx: u8

Temporal layer zero index (F=0)

ns: u8

Scalability structure headers N_S + 1 indicates the number of spatial layers present in the VP9 stream

y: bool

Each spatial layer’s frame resolution present

g: bool

PG description present flag.

ng: u8

N_G indicates the number of pictures in a Picture Group (PG)

width: Vec<u16>height: Vec<u16>pgtid: Vec<u8>

Temporal layer ID of pictures in a Picture Group

pgu: Vec<bool>

Switching up point of pictures in a Picture Group

pgpdiff: Vec<Vec<u8>>

Reference indices of pictures in a Picture Group